IMPORTANT NOTES ABOUT THE COMPIZ-RELOADED SFS
==============================================

----------------------------------------------------------------------------------------

**To view this document in the future, run command `compiz-help` in a terminal window.**

----------------------------------------------------------------------------------------

**If Compiz does not start, run command `wmswitcher` in a terminal window.**

----------------------------------------------------------------------------------------

You must install Python 3 and its dependencies before Compiz can be used.
Refer to section [Python 3 Dependency].

.

You might want to add a right-click menu to replace the Openbox Menu while Compiz is running.
Refer to section [Replacing the Openbox Application Menu].

.

**Unload any old Compiz-Reloaded SFS** files before proceeding.  
Old Compiz configuration files, or loading an old version of the compiz-reloaded SFS, will interfere with the programs in this SFS.
Backup then remove old configuration files; refer to section [Cleaning Old Configuration Files].

.

Loading Compiz SFS
------------------

In Fatdog64 Control Panel, select and run 'System > System SFS Loader' to ensure that the Compiz-Reloaded SFS is set to be loaded on reboot.
Failing this step, X will not start the next time your system will reboot.
If X does not start, type `xwin openbox` at the black screen prompt, and press the ENTER key.

----------------------------------------------------------------------------------------

If you use another compositing manager such as xcompmgr, compton, or picom, you must permanently disable it before starting Compiz; otherwise, your windows will become unmanageable.

----------------------------------------------------------------------------------------


### Python 3 Dependency

The following programs in the Compiz-Reloaded SFS require Python 3:

 * ccsm (CompizConfig Settings Manager)

 * emerald-theme-manager (Emerald Theme Manager)

 * fusion-icon (Fusion Icon)

Selecting Compiz as the Window Manager without all dependencies installed will lead to unpredictable results.

To meet all dependencies, either load the Fatdog64 DEVX SFS (get it with 'Control Panel > System > SFS Manager')
or install the following packages using the Gslapt Package Manager:

 * python3

 * python3-pygobject and its automatic dependencies

.

### Replacing the Openbox Application Menu

The Compiz Window Manager does not provide a Desktop Application Menu equivalent to the Openbox Menu.
To be clear, Openbox displays an Application Menu when the user right-clicks a free area of the X root window.
This menu is similar to the LXQt-panel's Application Menu.

The Fatdog64 package repository offers 'gmenu3', a stand-alone Application Menu alternative to the Openbox Menu.
When gmenu3 is installed, and Compiz enabled, right-clicking a free area of the root window will pop up the gmenu3 menu.
Consider installing the gmenu3 package—using none other than the GSlapt Package Manager.

* If you wish to use another right-click menu program instead of gmenu3,
  append the following line to /etc/compizconfig/compiz-session.ini.
  (If this file does not exist, load the SFS and start Compiz to create compiz-session.ini; then append the line):

  ```sh
    COMPIZ_MENU=/path/to/your/menu/program
  ```

  Replace the path with the actual filepath of the menu program.

.

### Cleaning Old Configuration Files

Old Compiz or Emerald configuration files can interfere with the programs in this SFS and lead to unpredictable results.

**Remove** (backup first, if desired) old configuration files before **switching the Window Manager**, such as:

  * /etc/compizconfig (the whole folder)
  * $HOME/.config/compiz (the whole folder)
  * $HOME/.emerald (the whole folder)
  * $HOME/.fatdog/windowmanager
  * Symbolic links and scripts that start Compiz in /etc/xdg/Startup and $HOME/Startup.

.

Unloading Compiz SFS
--------------------

This SFS will not unload successfully while any of the following processes are running:

* compiz-session
* emerald
* tail -f defaults.ini
* compiz
* emerald-theme-manager
* ccsm
* fusion-icon
* gtkdialog COMPIZ_SESSION

If you cannot unload the SFS without errors use a task manager, such as htop, lxtask, to kill the processes.
Then close this file and all folder windows that are open in the directory of this file.
Then try unloading the SFS again.

.

Selecting the Window Manager
----------------------------

You can switch the active window manager between JWM, Openbox and Compiz using any of these methods:

1. In the Application Menu, select 'Desktop > WM Switcher'.

2. If the [Fusion-icon] program is running, click its tray icon in the Panel and select 'Select Window Manager'

3. Open a terminal window and run the `wmswitcher` command.
   ```
   Usage: wmswitcher [compiz|jwm|openbox] [fusion-icon]
   ```
   - If the fusion-icon argument is provided, Fusion-icon is started and an autostart link is created in the `~/Startup/` directory.
   - If the autostart link already exists and the fusion-icon argument is omitted, the link is removed to disable Fusion-icon autostart.

.

Fusion-icon
-----------

Fusion-icon is an optional tray icon providing quick access to Compiz functions, and allowing to switch the window manager.
To permanently enable the Fusion-icon app, check the 'Fusion-icon' box in the wmswitcher dialog.
For occasional use, select 'Fusion Icon' in the 'Desktop' category of the Application Menu.

.

CompizConfig Settings Manager (CCSM)
------------------------------------

Start CCSM from the Fusion-icon menu or the 'Desktop' category of the Application Menu.

Do not increase the number of desktops (CCSM 'General Options > Desktop Size > Number of Desktops').
Keep the value 1, otherwise switching the Compiz workspace could lead to loss of the LXQt-panel and ROX Desktop icons.
> Instead you may change CCSM 'Horizontal/Vertical Virtual Size' in order to enable more workspaces.
The LxQt-panel desktop switcher can recognize and switch between these virtual workspaces (4 by default).

.

Don't enable 'Cube Atlantis' and 'Unredirect Fullscreen Windows' at the same time, because this combination could crash Compiz while X is starting".

.

Emerald Theme Manager
---------------------

Some themes may require additional fonts to match their screenshots exactly.
You need to install the missing fonts.


-----------------------------------------------------------------------------


QUESTIONS AND ANSWERS
=====================

**Q** It doesn't work! What next?

  **A** Run `wmswitcher` in a terminal window and look for error messages.

.

**Q** I can't get into my X desktop anymore! Now I'm staring at a black text console screen.

  **A** start X using: `xwin openbox`.

.

**Q** Tearing in video playback and/or poor FPS in fullscreen applications?

  **A** Enable 'Application Menu > Desktop > CCSM > General Options > General > Unredirect Fullscreen Windows'.

.

**Q** I used xscreenshot or xannotate. Now when I restart the X session (without rebooting), the screen is white / I can't see any window.

  **A** Run `xannotate -h` and verify that it does _not_ list option `-x`.
  Option `-x` was removed in Fatdog64 903 and the xannotate-2024.07 package.
  If your xannotate binary supports `-x` then it is an old xannotate–contained in your save file or loaded by an SFS–which must be removed.


-----------------------------------------------------------------------------


CHANGE LOG
==========

**[compiz-reloaded-2025.06]**

- Minimum required Fatdog64 version: **903**.

- Remove gmenu2 and gtkmenuplus from the SFS. Now the [IMPORTANT NOTES] screen tells users to install gmenu3.

- Update upstream sources: compiz-core, compiz-manager, compiz-plugins-extra, compiz-plugins-main.

- Update documentation.

- Improved SFS loading experience.

- Auto-restart the Emerald window decorator when it crashes.

- Fixed a problem where Fusion-icon did not terminate Emerald.

- Numerous other bug fixes and fine tunings.

**[compiz-reloaded-2024.02]**

- First SFS version for Fatdog64-900.
